@@ -6,8 +6,8 @@ from hue.cli.console import console
 from . import bridge, light
 
 app = typer.Typer(name="hue")
-app.add_typer(bridge.app, name="bridge", help="Interact with the Bridge API")
-app.add_typer(light.app, name="light", help="Interact with the Lights API")
+app.add_typer(bridge.app, name="bridge", help="Interact with the Hue Bridge API")
+app.add_typer(light.app, name="light", help="Interact with the Hue Lights API")
 
 
 @app.command()
